@@ -1,7 +1,7 @@
 package Forest::Tree::Reader;
 use Moose::Role;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'Forest::Tree::Loader';
@@ -14,7 +14,7 @@ sub load {
     $self->read(@_);
 }
 
-1;
+no Moose::Role; 1;
 
 __END__
 
@@ -69,7 +69,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Infinity Interactive, Inc.
+Copyright 2008-2009 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
