@@ -1,12 +1,12 @@
 package Forest::Tree::Roles::JSONable;
 use Moose::Role;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 requires 'as_json';
 
-no Moose; 1;
+no Moose::Role; 1;
 
 __END__
 
@@ -43,7 +43,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Infinity Interactive, Inc.
+Copyright 2008-2009 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
