@@ -1,7 +1,7 @@
 package Forest::Tree::Roles::MetaData;
 use Moose::Role;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'metadata' => (
@@ -33,7 +33,7 @@ sub fetch_metadata_for {
     return;
 }
 
-no Moose; 1;
+no Moose::Role; 1;
 
 __END__
 
@@ -82,7 +82,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Infinity Interactive, Inc.
+Copyright 2008-2009 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
